# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;
BEGIN { plan tests => 2 };
use Class::Listener;
ok(1); # If we made it this far, we're ok.

#########################

# Insert your test code below, the Test module is use()ed here so read
# its man page ( perldoc Test ) for help writing this test script.

use Class::Maker;

Class::Maker::class 'Dog',
{
	isa => [qw( Class::Listener )],
};

sub Dog::_on_command
{
	print "wow wow!\n";
	
return 1;
}

	$Class::Listener::DEBUG = 1;
	
	my $lessie = Dog->new();
	
ok( $lessie->Class::Listener::signal( 'command' ) );